#!/usr/bin/env python
# SPDX-License-Identifier: ISC

#
# test_ldp_oc_topo1.py
# Part of NetDEF Topology Tests
#
# Copyright (c) 2020 by by Volta Networks
#

r"""
test_ldp_oc_topo1.py: Simple FRR LDP Test

             +---------+
             |    r1   |
             | 1.1.1.1 |
             +----+----+
                  | .1  r1-eth0
                  |
            ~~~~~~~~~~~~~
          ~~     sw0     ~~
          ~~ 10.0.1.0/24 ~~
            ~~~~~~~~~~~~~
                  |10.0.1.0/24
                  |
                  | .2  r2-eth0
             +----+----+
             |    r2   |
             | 2.2.2.2 |
             +--+---+--+
    r2-eth2  .2 |   | .2  r2-eth1
         ______/     \______
        /                   \
  ~~~~~~~~~~~~~        ~~~~~~~~~~~~~
~~     sw2     ~~    ~~     sw1     ~~
~~ 10.0.3.0/24 ~~    ~~ 10.0.2.0/24 ~~
  ~~~~~~~~~~~~~        ~~~~~~~~~~~~~
        |                 /    |
         \      _________/     |
          \    /                \
r3-eth1 .3 |  | .3  r3-eth0      | .4 r4-eth0
      +----+--+---+         +----+----+
      |     r3    |         |    r4   |
      |  3.3.3.3  |         | 4.4.4.4 |
      +-----------+         +---------+
"""

import os
import sys
import pytest
import json
from functools import partial

# Save the Current Working Directory to find configuration files.
CWD = os.path.dirname(os.path.realpath(__file__))
sys.path.append(os.path.join(CWD, "../"))

# pylint: disable=C0413
# Import topogen and topotest helpers
from lib import topotest
from lib.topogen import Topogen, TopoRouter, get_topogen
from lib.topolog import logger

# Required to instantiate the topology builder class.

pytestmark = [pytest.mark.ldpd, pytest.mark.ospfd]


def build_topo(tgen):
    "Build function"

    #
    # Define FRR Routers
    #
    for router in ["r1", "r2", "r3", "r4"]:
        tgen.add_router(router)

    #
    # Define connections
    #
    switch = tgen.add_switch("s0")
    switch.add_link(tgen.gears["r1"])
    switch.add_link(tgen.gears["r2"])

    switch = tgen.add_switch("s1")
    switch.add_link(tgen.gears["r2"])
    switch.add_link(tgen.gears["r3"])
    switch.add_link(tgen.gears["r4"])

    switch = tgen.add_switch("s2")
    switch.add_link(tgen.gears["r2"])
    switch.add_link(tgen.gears["r3"])


def setup_module(mod):
    "Sets up the pytest environment"
    tgen = Topogen(build_topo, mod.__name__)
    tgen.start_topology()

    router_list = tgen.routers()

    # For all registered routers, load the zebra configuration file
    for rname, router in router_list.items():
        router.load_config(
            TopoRouter.RD_ZEBRA, os.path.join(CWD, "{}/zebra.conf".format(rname))
        )
        # Don't start ospfd and ldpd in the CE nodes
        if router.name[0] == "r":
            router.load_config(
                TopoRouter.RD_OSPF, os.path.join(CWD, "{}/ospfd.conf".format(rname))
            )
            router.load_config(
                TopoRouter.RD_LDP, os.path.join(CWD, "{}/ldpd.conf".format(rname))
            )

    tgen.start_router()


def teardown_module():
    "Teardown the pytest environment"
    tgen = get_topogen()

    # This function tears down the whole topology.
    tgen.stop_topology()


def router_compare_json_output(rname, command, reference):
    "Compare router JSON output"

    logger.info('Comparing router "%s" "%s" output', rname, command)

    tgen = get_topogen()
    filename = "{}/{}/{}".format(CWD, rname, reference)
    expected = json.loads(open(filename).read())

    # Run test function until we get an result. Wait at most 80 seconds.
    test_func = partial(topotest.router_json_cmp, tgen.gears[rname], command, expected)
    _, diff = topotest.run_and_expect(test_func, None, count=160, wait=0.5)

    assertmsg = '"{}" JSON output mismatches the expected result'.format(rname)
    assert diff is None, assertmsg


def test_ospf_convergence():
    logger.info("Test: check OSPF adjacencies")

    tgen = get_topogen()

    # Skip if previous fatal error condition is raised
    if tgen.routers_have_failure():
        pytest.skip(tgen.errors)

    for rname in ["r1", "r2", "r3", "r4"]:
        router_compare_json_output(
            rname, "show ip ospf neighbor json", "show_ip_ospf_neighbor.json"
        )


def test_rib():
    logger.info("Test: verify RIB")
    tgen = get_topogen()

    # Skip if previous fatal error condition is raised
    if tgen.routers_have_failure():
        pytest.skip(tgen.errors)

    for rname in ["r1", "r2", "r3", "r4"]:
        router_compare_json_output(rname, "show ip route json", "show_ip_route.ref")


def test_ldp_adjacencies():
    logger.info("Test: verify LDP adjacencies")
    tgen = get_topogen()

    # Skip if previous fatal error condition is raised
    if tgen.routers_have_failure():
        pytest.skip(tgen.errors)

    for rname in ["r1", "r2", "r3", "r4"]:
        router_compare_json_output(
            rname, "show mpls ldp discovery json", "show_ldp_discovery.ref"
        )


def test_ldp_neighbors():
    logger.info("Test: verify LDP neighbors")
    tgen = get_topogen()

    # Skip if previous fatal error condition is raised
    if tgen.routers_have_failure():
        pytest.skip(tgen.errors)

    for rname in ["r1", "r2", "r3", "r4"]:
        router_compare_json_output(
            rname, "show mpls ldp neighbor json", "show_ldp_neighbor.ref"
        )


def test_ldp_bindings():
    logger.info("Test: verify LDP bindings")
    tgen = get_topogen()

    # Skip if previous fatal error condition is raised
    if tgen.routers_have_failure():
        pytest.skip(tgen.errors)

    for rname in ["r1", "r2", "r3", "r4"]:
        router_compare_json_output(
            rname, "show mpls ldp binding json", "show_ldp_binding.ref"
        )


# Memory leak test template
def test_memory_leak():
    "Run the memory leak test and report results."
    tgen = get_topogen()
    if not tgen.is_memleak_enabled():
        pytest.skip("Memory leak test/report is disabled")

    tgen.report_memory_leaks()


if __name__ == "__main__":
    args = ["-s"] + sys.argv[1:]
    sys.exit(pytest.main(args))



import frrtest
import pytest

if 'S["SCRIPTING_TRUE"]=""\n' not in open("../config.status").readlines():
    class TestFrrlua:
        @pytest.mark.skipif(True, reason="Test unsupported")
        def test_exit_cleanly(self):
            pass
else:

    class TestFrrlua(frrtest.TestMultiOut):
        program = "./test_frrlua"

    TestFrrlua.exit_cleanly()



#!/usr/bin/env python
# SPDX-License-Identifier: GPL-2.0-or-later
#
# Copyright 2024 6WIND S.A.
#


"""
Test BGP OPEN NOTIFY (Configuration mismatch) followed by snmpwalk.
"""

import os
import sys
import json
import pytest
import functools

CWD = os.path.dirname(os.path.realpath(__file__))
sys.path.append(os.path.join(CWD, "../"))

# pylint: disable=C0413
# Import topogen and topotest helpers
from lib.topogen import Topogen, TopoRouter, get_topogen
from lib import topotest

pytestmark = [pytest.mark.bgpd, pytest.mark.snmp]


def build_topo(tgen):
    """Build function"""

    tgen.add_router("r2")
    tgen.add_router("rr")

    switch = tgen.add_switch("s1")
    switch.add_link(tgen.gears["r2"])
    switch.add_link(tgen.gears["rr"])


def setup_module(mod):
    snmpd = os.system("which snmpd")
    if snmpd:
        error_msg = "SNMP not installed - skipping"
        pytest.skip(error_msg)

    tgen = Topogen(build_topo, mod.__name__)
    tgen.start_topology()

    for rname, router in tgen.routers().items():
        router.load_config(
            TopoRouter.RD_ZEBRA, os.path.join(CWD, "{}/zebra.conf".format(rname))
        )
        router.load_config(
            TopoRouter.RD_BGP,
            os.path.join(CWD, "{}/bgpd.conf".format(rname)),
            "-M snmp",
        )
        router.load_config(
            TopoRouter.RD_SNMP,
            os.path.join(CWD, "{}/snmpd.conf".format(rname)),
            "-Le -Ivacm_conf,usmConf,iquery -V -DAgentX",
        )

    tgen.start_router()


def teardown_module(mod):
    tgen = get_topogen()
    tgen.stop_topology()


def test_bgp_open_notification_change_configuration():
    tgen = get_topogen()

    tgen.gears["rr"].vtysh_multicmd(
        """
configure terminal
router bgp 65004
neighbor 192.168.12.2  password 8888"
"""
    )
    tgen.net["r2"].cmd("snmpwalk -v 2c -c public 127.0.0.1 .1.3.6.1.4.1.7336.4.2.1")
    tgen.gears["rr"].vtysh_multicmd(
        """
configure terminal
router bgp 65004
no neighbor 192.168.12.2  password 8888"
"""
    )

    def _check_bgp_session():
        r2 = tgen.gears["r2"]

        output = json.loads(r2.vtysh_cmd("show bgp summary json"))
        expected = {
            "ipv4Unicast": {"peers": {"192.168.12.4": {"state": "Established"}}}
        }

        return topotest.json_cmp(output, expected)

    test_func1 = functools.partial(_check_bgp_session)
    _, result1 = topotest.run_and_expect(test_func1, None, count=120, wait=0.5)

    assert result1 is None, "Failed to verify the bgp session"


def test_memory_leak():
    "Run the memory leak test and report results."
    tgen = get_topogen()
    if not tgen.is_memleak_enabled():
        pytest.skip("Memory leak test/report is disabled")

    tgen.report_memory_leaks()


if __name__ == "__main__":
    args = ["-s"] + sys.argv[1:]
    sys.exit(pytest.main(args))



# -*- coding: utf-8 eval: (blacken-mode 1) -*-
# SPDX-License-Identifier: ISC
#
# May 2 2023, Christian Hopps <chopps@labn.net>
#
# Copyright (c) 2023, LabN Consulting, L.L.C.
#

"""
Verify large set of routes present when staticd (backend client) is started after it's
startup config is present during launch.
"""

import logging
import os

import pytest
from lib.common_config import step
from lib.topogen import Topogen, TopoRouter
from munet.base import Timeout
from util import check_kernel, check_vtysh_up, write_big_route_conf

CWD = os.path.dirname(os.path.realpath(__file__))

pytestmark = [pytest.mark.staticd, pytest.mark.mgmtd]

track = Timeout(0)
ROUTE_COUNT = 2500
ROUTE_RANGE = [None, None]


@pytest.fixture(scope="module")
def tgen(request):
    "Setup/Teardown the environment and provide tgen argument to tests"

    global start_time
    topodef = {
        "s1": ("r1",),
    }

    tgen = Topogen(topodef, request.module.__name__)
    tgen.start_topology()

    prologue = open(f"{CWD}/r1/mgmtd.conf").read()

    confpath = f"{tgen.gears['r1'].gearlogdir}/r1-late-big.conf"
    start, end = write_big_route_conf("10.0.0.0/8", ROUTE_COUNT, confpath, prologue)
    ROUTE_RANGE[0] = start
    ROUTE_RANGE[1] = end

    # configure mgmtd using current mgmtd config file
    tgen.gears["r1"].load_config(TopoRouter.RD_ZEBRA, "zebra.conf")
    tgen.gears["r1"].load_config(TopoRouter.RD_MGMTD, confpath)

    # Explicit disable staticd now..
    tgen.gears["r1"].net.daemons["staticd"] = 0

    tgen.start_router()
    yield tgen
    tgen.stop_topology()


def test_staticd_latestart(tgen):
    if tgen.routers_have_failure():
        pytest.skip(tgen.errors)

    r1 = tgen.routers()["r1"]

    check_vtysh_up(r1)
    logging.info("r1: vtysh connected after %ss", track.elapsed())

    result = check_kernel(r1, ROUTE_RANGE[0], retry_timeout=60, expected=False)
    assert result is not None, "first route present and should not be"
    result = check_kernel(r1, ROUTE_RANGE[1], retry_timeout=60, expected=False)
    assert result is not None, "last route present and should not be"

    step("Starting staticd")
    t2 = Timeout(0)
    r1.startDaemons(["staticd"])

    result = check_kernel(r1, ROUTE_RANGE[0], retry_timeout=60)
    assert result is None, "first route not present and should be"
    logging.info("r1: elapsed time for first route %ss", t2.elapsed())

    count = 0
    ocount = 0
    while count < ROUTE_COUNT:
        rc, o, e = r1.net.cmd_status("ip -o route | wc -l")
        if not rc:
            if count > ocount + 100:
                ocount = count
                logging.info("r1: elapsed time for %d routes %s", count, t2.elapsed())
            count = int(o)

    result = check_kernel(r1, ROUTE_RANGE[1], retry_timeout=1200)
    assert result is None, "last route not present and should be"
    logging.info("r1: elapsed time for last route %ss", t2.elapsed())



import inspect
import os
import subprocess

import frrtest
import pytest


class TestGRPC(object):
    program = "./test_grpc"

    @pytest.mark.skipif(
        'S["GRPC_TRUE"]=""\n' not in open("../config.status").readlines(),
        reason="GRPC not enabled",
    )
    @pytest.mark.skipif(
        not os.path.isdir("/usr/share/yang"),
        reason="YANG models aren't installed in /usr/share/yang",
    )
    def test_exits_cleanly(self):
        basedir = os.path.dirname(inspect.getsourcefile(type(self)))
        program = os.path.join(basedir, self.program)
        proc = subprocess.Popen(
            [frrtest.binpath(program)],
            stdin=subprocess.PIPE,
            stdout=subprocess.PIPE,
            stderr=subprocess.STDOUT,
        )
        output, _ = proc.communicate()
        self.exitcode = proc.wait()
        if self.exitcode != 0:
            print("OUTPUT:\n" + output.decode("ascii"))
            raise frrtest.TestExitNonzero(self)



#!/usr/bin/env python
# SPDX-License-Identifier: ISC

# Copyright (c) 2023 by
# Donatas Abraitis <donatas@opensourcerouting.org>
#

"""
Test if local-preference is passed between different EBGP peers when
EBGP-OAD is configured.

Also check if no-export community is passed to the EBGP-OAD peer.
"""

import os
import sys
import json
import pytest
import functools

pytestmark = [pytest.mark.bgpd]

CWD = os.path.dirname(os.path.realpath(__file__))
sys.path.append(os.path.join(CWD, "../"))

# pylint: disable=C0413
from lib import topotest
from lib.topogen import Topogen, get_topogen


def setup_module(mod):
    topodef = {"s1": ("r1", "r2", "r4"), "s2": ("r2", "r3"), "s3": ("r4", "r5")}
    tgen = Topogen(topodef, mod.__name__)
    tgen.start_topology()

    router_list = tgen.routers()

    for _, (rname, router) in enumerate(router_list.items(), 1):
        router.load_frr_config(os.path.join(CWD, "{}/frr.conf".format(rname)))

    tgen.start_router()


def teardown_module(mod):
    tgen = get_topogen()
    tgen.stop_topology()


def test_bgp_oad():
    tgen = get_topogen()

    if tgen.routers_have_failure():
        pytest.skip(tgen.errors)

    r1 = tgen.gears["r1"]
    r2 = tgen.gears["r2"]
    r3 = tgen.gears["r3"]
    r4 = tgen.gears["r4"]

    def _bgp_converge():
        output = json.loads(r1.vtysh_cmd("show bgp ipv4 unicast 10.10.10.10/32 json"))
        expected = {
            "paths": [
                {
                    "aspath": {"string": "65002 65003"},
                    "metric": 123,
                    "locPrf": 123,
                    "peer": {
                        "hostname": "r2",
                        "type": "external (oad)",
                    },
                },
                {
                    "aspath": {"string": "65004 65005"},
                    "metric": 123,
                    "locPrf": 123,
                    "bestpath": {"selectionReason": "Peer Type"},
                    "peer": {
                        "hostname": "r4",
                        "type": "external",
                    },
                },
            ]
        }
        return topotest.json_cmp(output, expected)

    test_func = functools.partial(
        _bgp_converge,
    )
    _, result = topotest.run_and_expect(test_func, None, count=30, wait=1)
    assert result is None, "Can't converge"

    def _bgp_check_no_export(router, arg=[{"valid": True}]):
        output = json.loads(router.vtysh_cmd("show bgp ipv4 unicast json"))
        expected = {
            "routes": {
                "10.10.10.1/32": arg,
            }
        }
        return topotest.json_cmp(output, expected)

    test_func = functools.partial(
        _bgp_check_no_export,
        r2,
    )
    _, result = topotest.run_and_expect(test_func, None, count=30, wait=1)
    assert result is None, "10.10.10.1/32 should be advertised to r2"

    test_func = functools.partial(
        _bgp_check_no_export,
        r3,
    )
    _, result = topotest.run_and_expect(test_func, None, count=30, wait=1)
    assert result is None, "10.10.10.1/32 should be advertised to r3"

    test_func = functools.partial(
        _bgp_check_no_export,
        r4,
        None,
    )
    _, result = topotest.run_and_expect(test_func, None, count=30, wait=1)
    assert result is None, "10.10.10.1/32 should not be advertised to r4 (not OAD peer)"


if __name__ == "__main__":
    args = ["-s"] + sys.argv[1:]
    sys.exit(pytest.main(args))



#!/usr/bin/python

#
# Copyright (c) 2022 by VMware, Inc. ("VMware")
# Used Copyright (c) 2018 by Network Device Education Foundation, Inc.
# ("NetDEF") in this file.
#
# Permission to use, copy, modify, and/or distribute this software
# for any purpose with or without fee is hereby granted, provided
# that the above copyright notice and this permission notice appear
# in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND VMWARE DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL VMWARE BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY
# DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
# WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
# ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE
# OF THIS SOFTWARE.
#


"""OSPF Basic Functionality Automation."""
import os
import sys
import time
import pytest
from time import sleep

# Save the Current Working Directory to find configuration files.
CWD = os.path.dirname(os.path.realpath(__file__))
sys.path.append(os.path.join(CWD, "../"))
sys.path.append(os.path.join(CWD, "../lib/"))

pytestmark = [pytest.mark.ospfd, pytest.mark.staticd]
# Global variables
topo = None

# pylint: disable=C0413
# Import topogen and topotest helpers
from lib.topolog import logger
from lib.topojson import build_config_from_json

# Import topoJson from lib, to create topology and initial configuration
from lib.common_config import (
    start_topology,
    write_test_header,
    write_test_footer,
    reset_config_on_routers,
    create_static_routes,
    step,
    topo_daemons,
    check_router_status,
    start_topology,
    write_test_header,
    write_test_footer,
    reset_config_on_routers,
    create_static_routes,
    step,
    shutdown_bringup_interface,
    check_router_status,
    start_topology,
    write_test_header,
    write_test_footer,
    reset_config_on_routers,
    step,
    create_static_routes,
    kill_router_daemons,
    check_router_status,
    start_router_daemons,
)
from lib.topolog import logger
from lib.topogen import Topogen, get_topogen

from lib.topojson import build_config_from_json
from lib.ospf import (
    verify_ospf_neighbor,
    clear_ospf,
    create_router_ospf,
    verify_ospf_database,
    get_ospf_database,
)

# Global variables
topo = None
NETWORK = {
    "ipv4": [
        "11.0.20.1/32",
        "11.0.20.2/32",
        "11.0.20.3/32",
        "11.0.20.4/32",
        "11.0.20.5/32",
    ]
}
"""
TOPOOLOGY =
      Please view in a fixed-width font such as Courier.
      +---+  A1       +---+
      +R1 +------------+R2 |
      +-+-+-           +--++
        |  --        --  |
        |    -- A0 --    |
      A0|      ----      |
        |      ----      | A2
        |    --    --    |
        |  --        --  |
      +-+-+-            +-+-+
      +R0 +-------------+R3 |
      +---+     A3     +---+

TESTCASES =
1. Verify OSPF Flood reduction functionality with ospf enabled on process level.
2. Verify OSPF Flood reduction functionality with ospf enabled on area level.
3. Verify OSPF Flood reduction functionality between different area's.
4. Verify OSPF Flood reduction functionality with ospf enabled on process level with default lsa refresh timer.
5. Chaos - Verify OSPF TTL GTSM and flood  reduction functionality in chaos scenarios.
"""


def setup_module(mod):
    """
    Sets up the pytest environment

    * `mod`: module name
    """
    global topo
    testsuite_run_time = time.asctime(time.localtime(time.time()))
    logger.info("Testsuite start time: {}".format(testsuite_run_time))
    logger.info("=" * 40)

    logger.info("Running setup_module to create topology")

    # This function initiates the topology build with Topogen...
    json_file = "{}/ospf_flood_reduction.json".format(CWD)
    tgen = Topogen(json_file, mod.__name__)
    global topo
    topo = tgen.json_topo
    # ... and here it calls Mininet initialization functions.

    # get list of daemons needs to be started for this suite.
    daemons = topo_daemons(tgen)

    # Starting topology, create tmp files which are loaded to routers
    #  to start daemons and then start routers
    start_topology(tgen)

    # Creating configuration from JSON
    build_config_from_json(tgen, topo)

    # Don't run this test if we have any failure.
    if tgen.routers_have_failure():
        pytest.skip(tgen.errors)
    # Api call verify whether OSPF is converged
    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "setup_module :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    logger.info("Running setup_module() done")


def teardown_module():
    """
    Teardown the pytest environment.

    * `mod`: module name
    """

    logger.info("Running teardown_module to delete topology")

    tgen = get_topogen()

    # Stop toplogy and Remove tmp files
    tgen.stop_topology()

    logger.info(
        "Testsuite end time: {}".format(time.asctime(time.localtime(time.time())))
    )
    logger.info("=" * 40)


def red_static(dut, config=True):
    """Local def for Redstribute static routes inside ospf."""
    global topo
    tgen = get_topogen()
    if config:
        ospf_red = {dut: {"ospf": {"redistribute": [{"redist_type": "static"}]}}}
    else:
        ospf_red = {
            dut: {
                "ospf": {
                    "redistribute": [{"redist_type": "static", "del_action": True}]
                }
            }
        }
    result = create_router_ospf(tgen, topo, ospf_red)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)


# ##################################
# Test cases start here.
# ##################################
def test_ospf_flood_red_tc1_p0(request):
    """Verify OSPF Flood reduction functionality with ospf enabled on process level."""
    tc_name = request.node.name
    write_test_header(tc_name)
    tgen = get_topogen()

    # Don't run this test if we have any failure.
    if tgen.routers_have_failure():
        check_router_status(tgen)

    global topo

    step("Bring up the base config as per the topology")
    reset_config_on_routers(tgen)
    red_static("r0")
    step("Base config should be up, verify using OSPF convergence on all the routers")

    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "Testcase :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    input_dict = {
        "r0": {
            "static_routes": [
                {
                    "network": NETWORK["ipv4"][0],
                    "no_of_ip": 5,
                    "next_hop": "Null0",
                }
            ]
        }
    }
    result = create_static_routes(tgen, input_dict)
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    step("Enable flood reduction in process level on R0")
    ospf_flood = {"r0": {"ospf": {"flood-reduction": True}}}
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    step("Verify that ospf lsa's are set with dc bit 1.")
    dut = "r0"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {
                        "lsaId": "100.1.1.0",
                        "options": "*|-|DC|-|-|-|E|-",
                    },
                ]
            }
        },
    }
    result = verify_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    step("Configure the custom refresh timer")
    ospf_flood = {"r0": {"ospf": {"lsa-refresh": 120}}}
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    step("Enable flood. reduction in all the routers of the topology.")
    for rtr in topo["routers"].keys():
        ospf_flood = {rtr: {"ospf": {"lsa-refresh": 120, "flood-reduction": True}}}
        result = create_router_ospf(tgen, topo, ospf_flood)
        assert result is True, "Testcase : Failed \n Error: {}".format(result)

    for rtr in topo["routers"]:
        clear_ospf(tgen, rtr)

    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "Testcase :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    step("Verify that ospf lsa's are set with dc bit 1.")
    for rtr in topo["routers"]:
        dut = rtr
        lsid = "{}".format(topo["routers"][rtr]["ospf"]["router_id"])
        input_dict_db = {
            "routerId": lsid,
            "areas": {
                "0.0.0.0": {
                    "routerLinkStates": [
                        {
                            "lsaId": lsid,
                            "options": "*|-|DC|-|-|-|E|-",
                        },
                    ]
                }
            },
        }
        result = verify_ospf_database(
            tgen, topo, dut, input_dict_db, lsatype="router", rid=lsid
        )
        assert result is True, "Testcase {} : Failed \n Error: {}".format(
            tc_name, result
        )

    step("Wait for 120 secs and verify that LSA's are not refreshed. ")
    # get LSA age
    dut = "r1"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {"lsaId": "100.1.1.0", "lsaAge": "get"},
                ]
            }
        },
    }
    sleep(10)

    result1 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    # this wait is put so that we wait for 5secs to check if lsa is refreshed.
    sleep(5)
    result2 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )

    assert (result1 == result2) is True, "Testcase {} : Failed \n Error: {}".format(
        tc_name, result
    )

    step("Disable flood reduction in R0.")
    ospf_flood = {
        "r0": {"ospf": {"flood-reduction": True, "del_flood_reduction": True}}
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    clear_ospf(tgen, "r0")

    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "Testcase :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    step("Verify that ospf lea's are not set with dc bit 1.")
    dut = "r0"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {
                        "lsaId": "100.1.1.0",
                        "options": "*|-|DC|-|-|-|E|-",
                    },
                ]
            }
        },
    }
    result = verify_ospf_database(
        tgen,
        topo,
        dut,
        input_dict_db,
        lsatype="router",
        rid="100.1.1.0",
        expected=False,
    )
    assert result is not True, (
        "Testcase {} : Failed \n "
        "Expected: OSPF LSA should not be set with DC bit in {} \n "
        "Found: {}".format(tc_name, dut, result)
    )
    step("Wait for 120 secs and verify that LSA's are not refreshed. ")
    # get LSA age
    dut = "r1"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {"lsaId": "100.1.1.0", "lsaAge": "get"},
                ]
            }
        },
    }
    sleep(10)

    result1 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    sleep(5)
    result2 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )

    if result2 is not result1:
        result = True
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    step(
        "Enable flood reduction on each router with 10 secs delay of between each router."
    )
    for rtr in topo["routers"].keys():
        ospf_flood = {rtr: {"ospf": {"lsa-refresh": 120, "flood-reduction": True}}}
        sleep(10)
        result = create_router_ospf(tgen, topo, ospf_flood)
        assert result is True, "Testcase : Failed \n Error: {}".format(result)

    for rtr in topo["routers"]:
        clear_ospf(tgen, rtr)

    step("Verify that LSA's are not refreshed. Do not age bit should be set to 1.")
    dut = "r0"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {
                        "lsaId": "100.1.1.0",
                        "options": "*|-|DC|-|-|-|E|-",
                    },
                ]
            }
        },
    }
    result = verify_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    step(
        "Verify OSPF neighborship when OSPF flood reduction  is configured and ospf process is restarted"
    )

    step("Kill OSPFd daemon on R0.")
    kill_router_daemons(tgen, "r0", ["ospfd"])
    start_router_daemons(tgen, "r0", ["ospfd"])

    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "Testcase :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    step("Verify that LSA's are not refreshed. Do not age bit should be set to 1.")
    dut = "r0"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {
                        "lsaId": "100.1.1.0",
                        "options": "*|-|DC|-|-|-|E|-",
                    },
                ]
            }
        },
    }
    result = verify_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    write_test_footer(tc_name)


def test_ospf_flood_red_tc2_p0(request):
    """Verify OSPF Flood reduction functionality with ospf enabled on area level."""
    tc_name = request.node.name
    write_test_header(tc_name)
    tgen = get_topogen()

    # Don't run this test if we have any failure.
    if tgen.routers_have_failure():
        check_router_status(tgen)

    global topo

    step("Bring up the base config as per the topology")
    reset_config_on_routers(tgen)
    red_static("r0")
    step("Base config should be up, verify using OSPF convergence on all the routers")

    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "Testcase :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    input_dict = {
        "r0": {
            "static_routes": [
                {
                    "network": NETWORK["ipv4"][0],
                    "no_of_ip": 5,
                    "next_hop": "Null0",
                }
            ]
        }
    }
    result = create_static_routes(tgen, input_dict)
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    step("Enable flood reduction in area level on R0 in area 0")
    ospf_flood = {
        "r0": {"ospf": {"area": [{"id": "0.0.0.0", "flood-reduction": True}]}}
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    step("Verify that ospf lsa's are set with dc bit 1.")
    dut = "r0"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {
                        "lsaId": "100.1.1.0",
                        "options": "*|-|DC|-|-|-|E|-",
                    },
                ]
            }
        },
    }
    result = verify_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    step("Configure the custom refresh timer")
    ospf_flood = {"r0": {"ospf": {"lsa-refresh": 120}}}
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    step("Enable flood. reduction in all the routers of the topology.")
    for rtr in topo["routers"].keys():
        ospf_flood = {
            rtr: {"ospf": {"area": [{"id": "0.0.0.0", "flood-reduction": True}]}}
        }
        result = create_router_ospf(tgen, topo, ospf_flood)
        assert result is True, "Testcase : Failed \n Error: {}".format(result)

    for rtr in topo["routers"]:
        clear_ospf(tgen, rtr)

    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "Testcase :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    step("Verify that ospf lsa's are set with dc bit 1.")
    for rtr in topo["routers"]:
        dut = rtr
        lsid = "{}".format(topo["routers"][rtr]["ospf"]["router_id"])
        input_dict_db = {
            "routerId": lsid,
            "areas": {
                "0.0.0.0": {
                    "routerLinkStates": [
                        {
                            "lsaId": lsid,
                            "options": "*|-|DC|-|-|-|E|-",
                        },
                    ]
                }
            },
        }
        result = verify_ospf_database(
            tgen, topo, dut, input_dict_db, lsatype="router", rid=lsid
        )
        assert result is True, "Testcase {} : Failed \n Error: {}".format(
            tc_name, result
        )

    step("Wait for 120 secs and verify that LSA's are not refreshed. ")
    # get LSA age
    dut = "r1"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {"lsaId": "100.1.1.0", "lsaAge": "get"},
                ]
            }
        },
    }
    sleep(10)

    result1 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    sleep(5)
    result2 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )

    assert (result1 == result2) is True, "Testcase {} : Failed \n Error: {}".format(
        tc_name, result
    )

    step("Disable flood reduction in R0.")
    ospf_flood = {
        "r0": {
            "ospf": {
                "area": [{"id": "0.0.0.0", "flood-reduction": True, "delete": True}]
            }
        }
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    clear_ospf(tgen, "r0")

    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "Testcase :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    step("Verify that ospf lea's are not set with dc bit 1.")
    dut = "r0"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {
                        "lsaId": "100.1.1.0",
                        "options": "*|-|DC|-|-|-|E|-",
                    },
                ]
            }
        },
    }
    result = verify_ospf_database(
        tgen,
        topo,
        dut,
        input_dict_db,
        lsatype="router",
        rid="100.1.1.0",
        expected=False,
    )
    assert result is not True, (
        "Testcase {} : Failed \n "
        "Expected: OSPF LSA should not be set with DC bit in {} \n "
        "Found: {}".format(tc_name, dut, result)
    )
    step("Wait for 120 secs and verify that LSA's are not refreshed. ")
    # get LSA age
    dut = "r1"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {"lsaId": "100.1.1.0", "lsaAge": "get"},
                ]
            }
        },
    }
    sleep(10)

    result1 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    sleep(5)
    result2 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )

    if result2 is not result1:
        result = True
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    step(
        "Enable flood reduction on each router with 10 secs delay of between each router."
    )
    for rtr in topo["routers"].keys():
        ospf_flood = {
            rtr: {"ospf": {"area": [{"id": "0.0.0.0", "flood-reduction": True}]}}
        }
        sleep(10)
        result = create_router_ospf(tgen, topo, ospf_flood)
        assert result is True, "Testcase : Failed \n Error: {}".format(result)

    for rtr in topo["routers"]:
        clear_ospf(tgen, rtr)

    step("Verify that LSA's are not refreshed. Do not age bit should be set to 1.")
    dut = "r0"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {
                        "lsaId": "100.1.1.0",
                        "options": "*|-|DC|-|-|-|E|-",
                    },
                ]
            }
        },
    }
    result = verify_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    write_test_footer(tc_name)


def test_ospf_flood_red_tc3_p0(request):
    """Verify OSPF Flood reduction functionality between different area's"""
    tc_name = request.node.name
    write_test_header(tc_name)
    tgen = get_topogen()

    # Don't run this test if we have any failure.
    if tgen.routers_have_failure():
        check_router_status(tgen)

    global topo

    step("Bring up the base config as per the topology")
    reset_config_on_routers(tgen)
    red_static("r0")
    step("Base config should be up, verify using OSPF convergence on all the routers")

    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "Testcase :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    input_dict = {
        "r0": {
            "static_routes": [
                {
                    "network": NETWORK["ipv4"][0],
                    "no_of_ip": 5,
                    "next_hop": "Null0",
                }
            ]
        }
    }
    result = create_static_routes(tgen, input_dict)
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    step("Enable flood reduction in area level on R0 in area 0")
    ospf_flood = {
        "r0": {"ospf": {"area": [{"id": "0.0.0.0", "flood-reduction": True}]}}
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    step("Verify that ospf lsa's are set with dc bit 1.")
    dut = "r0"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {
                        "lsaId": "100.1.1.0",
                        "options": "*|-|DC|-|-|-|E|-",
                    },
                ]
            }
        },
    }
    result = verify_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    step("Configure the custom refresh timer")
    ospf_flood = {"r0": {"ospf": {"lsa-refresh": 120}}}
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    step(
        "Enable flood. reduction in all the routers of the topology in area 0. Redistribute static route in area 0 R1 and area1 in R2."
    )
    for rtr in topo["routers"].keys():
        ospf_flood = {
            rtr: {"ospf": {"area": [{"id": "0.0.0.0", "flood-reduction": True}]}}
        }
        result = create_router_ospf(tgen, topo, ospf_flood)
        assert result is True, "Testcase : Failed \n Error: {}".format(result)

    sleep(10)

    for rtr in topo["routers"]:
        clear_ospf(tgen, rtr)

    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "Testcase :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    step("Verify that ospf lsa's are set with dc bit 1.")
    for rtr in topo["routers"]:
        dut = rtr
        lsid = "{}".format(topo["routers"][rtr]["ospf"]["router_id"])
        input_dict_db = {
            "routerId": lsid,
            "areas": {
                "0.0.0.0": {
                    "routerLinkStates": [
                        {
                            "lsaId": lsid,
                            "options": "*|-|DC|-|-|-|E|-",
                        },
                    ]
                }
            },
        }
        result = verify_ospf_database(
            tgen, topo, dut, input_dict_db, lsatype="router", rid=lsid
        )
        assert result is True, "Testcase {} : Failed \n Error: {}".format(
            tc_name, result
        )

    step("Wait for 120 secs and verify that LSA's are not refreshed. ")
    # get LSA age
    dut = "r1"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {"lsaId": "100.1.1.0", "lsaAge": "get"},
                ]
            }
        },
    }
    sleep(10)

    result1 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    sleep(5)
    result2 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )

    assert (result1 == result2) is True, "Testcase {} : Failed \n Error: {}".format(
        tc_name, result
    )

    step("Enable flood reduction in area 1.")

    ospf_flood = {
        "r0": {"ospf": {"area": [{"id": "0.0.0.0", "flood-reduction": True}]}}
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    ospf_flood = {
        "r1": {
            "ospf": {
                "area": [
                    {"id": "0.0.0.0", "flood-reduction": True},
                    {"id": "0.0.0.1", "flood-reduction": True},
                ]
            }
        }
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    ospf_flood = {
        "r2": {
            "ospf": {
                "area": [
                    {"id": "0.0.0.0", "flood-reduction": True},
                    {"id": "0.0.0.1", "flood-reduction": True},
                    {"id": "0.0.0.2", "flood-reduction": True},
                ]
            }
        }
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    ospf_flood = {
        "r3": {
            "ospf": {
                "area": [
                    {"id": "0.0.0.0", "flood-reduction": True},
                    {"id": "0.0.0.2", "flood-reduction": True},
                ]
            }
        }
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    for rtr in topo["routers"]:
        clear_ospf(tgen, rtr)

    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "Testcase :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    step("Verify that ospf lea's are  set with dc bit 1.")
    dut = "r1"
    input_dict_db = {
        "routerId": "100.1.1.1",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {
                        "lsaId": "100.1.1.1",
                        "options": "*|-|DC|-|-|-|E|-",
                    },
                ]
            }
        },
    }
    result = verify_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.1"
    )
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    step("Wait for 120 secs and verify that LSA's are not refreshed. ")
    # get LSA age
    dut = "r1"
    input_dict_db = {
        "routerId": "100.1.1.1",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {"lsaId": "100.1.1.1", "lsaAge": "get"},
                ]
            }
        },
    }
    sleep(10)

    result1 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.1"
    )
    sleep(5)
    result2 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.1"
    )

    if result2 is result1:
        result = True
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    step("Disable flood reduction in R0.")

    ospf_flood = {
        "r0": {
            "ospf": {
                "area": [{"id": "0.0.0.0", "flood-reduction": True, "delete": True}]
            }
        }
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    ospf_flood = {
        "r1": {
            "ospf": {
                "area": [
                    {"id": "0.0.0.0", "flood-reduction": True, "delete": True},
                    {"id": "0.0.0.1", "flood-reduction": True, "delete": True},
                ]
            }
        }
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    ospf_flood = {
        "r2": {
            "ospf": {
                "area": [
                    {"id": "0.0.0.0", "flood-reduction": True, "delete": True},
                    {"id": "0.0.0.1", "flood-reduction": True, "delete": True},
                    {"id": "0.0.0.2", "flood-reduction": True, "delete": True},
                ]
            }
        }
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    ospf_flood = {
        "r3": {
            "ospf": {
                "area": [
                    {"id": "0.0.0.0", "flood-reduction": True, "delete": True},
                    {"id": "0.0.0.2", "flood-reduction": True, "delete": True},
                ]
            }
        }
    }
    result = create_router_ospf(tgen, topo, ospf_flood)
    assert result is True, "Testcase : Failed \n Error: {}".format(result)

    clear_ospf(tgen, "r0")

    ospf_covergence = verify_ospf_neighbor(tgen, topo)
    assert ospf_covergence is True, "Testcase :Failed \n Error:" " {}".format(
        ospf_covergence
    )

    step("Verify that ospf lea's are not set with dc bit 1.")
    dut = "r0"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {
                        "lsaId": "100.1.1.0",
                        "options": "*|-|DC|-|-|-|E|-",
                    },
                ]
            }
        },
    }
    result = verify_ospf_database(
        tgen,
        topo,
        dut,
        input_dict_db,
        lsatype="router",
        rid="100.1.1.0",
        expected=False,
    )

    assert result is not True, (
        "Testcase {} : Failed \n "
        "Expected: OSPF LSA should not be set with DC bit in {} \n "
        "Found: {}".format(tc_name, dut, result)
    )

    step("Wait for 120 secs and verify that LSA's are not refreshed. ")
    # get LSA age
    dut = "r1"
    input_dict_db = {
        "routerId": "100.1.1.0",
        "areas": {
            "0.0.0.0": {
                "routerLinkStates": [
                    {"lsaId": "100.1.1.0", "lsaAge": "get"},
                ]
            }
        },
    }
    sleep(10)

    result1 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )
    sleep(5)
    result2 = get_ospf_database(
        tgen, topo, dut, input_dict_db, lsatype="router", rid="100.1.1.0"
    )

    if result2 is not result1:
        result = True
    assert result is True, "Testcase {} : Failed \n Error: {}".format(tc_name, result)

    write_test_footer(tc_name)


if __name__ == "__main__":
    args = ["-s"] + sys.argv[1:]
    sys.exit(pytest.main(args))
